@@ -16,7 +16,6 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Standard libraries
-import os.path
 import sys
 import re
 import sqlite3
@@ -314,7 +313,7 @@ def parse_args_tblock() -> None:
     elif parser.action == 'add-custom':
         data = []
         for filter_id in parser.values:
-            data.append([filter_id, 'b', os.path.realpath(parser.values[parser.values.index(filter_id) + 1])])
+            data.append([filter_id, 'b', parser.values[parser.values.index(filter_id) + 1]])
             parser.values.pop(parser.values.index(filter_id) + 1)
         if parser.options['with-sync']:
             sync_remote_repo(parser.options['force'])
