@@ -50,9 +50,9 @@ class Var:
     # The list of all official mirrors of the remote filter repository that are available
     # Read more: https://tblock.codeberg.page/wiki/filters/remote-repository#mirrors
     REPO_MIRRORS = [
-        'https://codeberg.org/tblock/remote-filters-repository/raw/branch/main/index.xml',
-        'https://0xacab.org/twann/remote-filters-repository-mirror/-/raw/main/index.xml',
-        'https://git.disroot.org/tblock/remote-filters-repository/raw/branch/main/index.xml',
+        'https://codeberg.org/tblock/repo/raw/branch/main/index.xml',
+        'https://0xacab.org/twann/repo/-/raw/main/index.xml',
+        'https://git.disroot.org/tblock/repo/raw/branch/main/index.xml',
         'https://tblock.codeberg.page/repo/index.xml'
     ]
 
