@@ -783,11 +783,12 @@ def search_filters(query: str, online_only: bool = False, custom_only: bool = Fa
         filters_list = get_all_id(subscribing, not_subscribing)
 
     for filter_id in filters_list:
-        if re.findall(regex_query, Filter(filter_id).id):
+        filter_match = Filter(filter_id)
+        if re.findall(regex_query, filter_match.id):
             print(filter_id)
-        elif re.findall(regex_query, Filter(filter_id).metadata['title']):
+        elif filter_match.on_rfr and re.findall(regex_query, filter_match.metadata['title']):
             print(filter_id)
-        elif re.findall(regex_query, Filter(filter_id).metadata['description']):
+        elif filter_match.on_rfr and re.findall(regex_query, filter_match.metadata['description']):
             print(filter_id)
         else:
             pass
