@@ -9,6 +9,7 @@ from nose.tools import raises
 
 tblock.config.Path.HOSTS = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', 'hosts')
 tblock.config.Path.DATABASE = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', 'storage.sqlite')
+tblock.config.Path.DB_LOCK = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', '.db-lock')
 tblock.config.Path.TMP_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root')
 tblock.config.Path.HOSTS_VERIFICATION = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'root', 'verification')
 tblock.config.setup_database(tblock.config.Path.DATABASE)
@@ -46,6 +47,10 @@ class TestUserRules(unittest.TestCase):
         )
 
     def test_user_rule_delete(self):
+        try:
+            os.remove(tblock.config.Path.DB_LOCK)
+        except FileNotFoundError:
+            pass
         self.assertEquals(
             tblock.rules.delete_rules(['www.example.com', 'www.example.org'], force=True),
             None
